@@ -1,4 +1,4 @@
-/* $Id: buffer.c,v 1.10 2002/01/31 17:54:49 ukai Exp $ */
+/* $Id: buffer.c,v 1.13 2002/03/15 19:02:40 ukai Exp $ */
 #include "fm.h"
 
 #ifdef USE_MOUSE
@@ -502,7 +502,6 @@ reshapeBuffer(Buffer *buf)
 		&f);
     if (f.stream == NULL)
 	return;
-
     copyBuffer(&sbuf, buf);
     clearBuffer(buf);
     while (buf->frameset) {
@@ -520,6 +519,21 @@ reshapeBuffer(Buffer *buf)
     UseContentCharset = FALSE;
     UseAutoDetect = FALSE;
 #endif
+    if (buf->search_header && buf->currentURL.scheme == SCM_LOCAL) {
+	if (buf->header_source && (buf->mailcap_source ||
+				   !strcmp(buf->currentURL.file, "-"))) {
+	    URLFile h;
+	    init_stream(&h, SCM_LOCAL, NULL);
+	    examineFile(buf->header_source, &h);
+	    if (h.stream) {
+		readHeader(&h, buf, TRUE, NULL);
+		UFclose(&h);
+	    }
+	}
+	else
+	    readHeader(&f, buf, TRUE, NULL);
+    }
+
     if (!strcasecmp(buf->type, "text/html"))
 	loadHTMLBuffer(&f, buf);
     else
