@@ -1,4 +1,4 @@
-/* $Id: etc.c,v 1.19 2002/02/19 15:50:18 ukai Exp $ */
+/* $Id: etc.c,v 1.22 2002/06/07 15:46:44 ukai Exp $ */
 #include "fm.h"
 #include <pwd.h>
 #include "myctype.h"
@@ -25,54 +25,6 @@
 #endif				/* __WATT32__ */
 
 
-#ifndef HAVE_STRCHR
-char *
-strchr(char *s, char c)
-{
-    while (*s) {
-	if (*s == c)
-	    return s;
-	s++;
-    }
-    return NULL;
-}
-#endif				/* not HAVE_STRCHR */
-
-#ifndef HAVE_STRCASECMP
-int
-strcasecmp(char *s1, char *s2)
-{
-    int x;
-    while (*s1) {
-	x = tolower(*s1) - tolower(*s2);
-	if (x != 0)
-	    break;
-	s1++;
-	s2++;
-    }
-    if (x != 0)
-	return x;
-    return -tolower(*s2);
-}
-
-int
-strncasecmp(char *s1, char *s2, int n)
-{
-    int x;
-    while (*s1 && n) {
-	x = tolower(*s1) - tolower(*s2);
-	if (x != 0)
-	    break;
-	s1++;
-	s2++;
-	n--;
-    }
-    if (x != 0)
-	return x;
-    return 0;
-}
-#endif				/* not HAVE_STRCASECMP */
-
 int
 columnSkip(Buffer *buf, int offset)
 {
@@ -1075,7 +1027,7 @@ mySystem(char *command, int background)
 	flush_tty();
 	if ((pid = fork()) == 0) {
 	    reset_signals();
-	    setpgrp();
+	    SETPGRP();
 	    close_tty();
 	    fclose(stdout);
 	    fclose(stderr);
@@ -1143,7 +1095,7 @@ myEditor(char *cmd, char *file, int line)
     if (!set_file) {
 	if (tmp == NULL)
 	    tmp = Strnew_charp(cmd);
-	if (!set_line && line > 0 && strcasestr(cmd, "vi"))
+	if (!set_line && line > 1 && strcasestr(cmd, "vi"))
 	    Strcat(tmp, Sprintf(" +%d", line));
 	Strcat_m_charp(tmp, " ", file, NULL);
     }
