@@ -1,4 +1,4 @@
-/* $Id: fm.h,v 1.53 2002/02/28 16:15:41 ukai Exp $ */
+/* $Id: fm.h,v 1.60 2002/06/01 16:50:16 ukai Exp $ */
 /* 
  * w3m: WWW wo Miru utility
  * 
@@ -20,6 +20,8 @@
 #include <string.h>
 #include <unistd.h>
 #include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
 #include "config.h"
 #include "history.h"
 
@@ -99,7 +101,6 @@ void bzero(void *, int);
 #define PIPEBUFFERNAME	"*stream*"
 #define CPIPEBUFFERNAME	"*stream(closed)*"
 #ifdef USE_DICT
-#define DICTCMD "w3mdict"
 #define DICTBUFFERNAME "*dictionary*"
 #endif				/* USE_DICT */
 
@@ -430,6 +431,7 @@ typedef struct _Buffer {
     char *edit;
     struct mailcap *mailcap;
     char *mailcap_source;
+    char *header_source;
     char search_header;
 #ifdef USE_SSL
     char *ssl_certificate;
@@ -517,10 +519,10 @@ struct readbuffer {
 #define RB_XMPMODE	0x02
 #define RB_LSTMODE	0x04
 #define RB_PLAIN	0x08
-#define RB_LEFT		0x00
+#define RB_LEFT		0x80000
 #define RB_CENTER	0x10
 #define RB_RIGHT	0x20
-#define RB_ALIGN	(RB_CENTER | RB_RIGHT)
+#define RB_ALIGN	(RB_LEFT| RB_CENTER | RB_RIGHT)
 #define RB_NOBR		0x40
 #define RB_P		0x80
 #define RB_PRE_INT	0x100
@@ -537,6 +539,7 @@ struct readbuffer {
 #define RB_TITLE	0x8000
 #define RB_NFLUSHED	0x10000
 #define RB_NOFRAMES	0x20000
+#define RB_INTABLE	0x40000
 
 #ifdef FORMAT_NICE
 #define RB_FILL		0x200000
@@ -763,9 +766,7 @@ global Buffer *Currentbuf;
 global Buffer *Firstbuf;
 global int CurrentKey;
 global char *CurrentKeyData;
-#ifdef USE_MENU
-global char *CurrentMenuData;
-#endif
+global char *CurrentCmdData;
 extern char *ullevel[];
 
 extern char *w3m_version;
@@ -814,6 +815,7 @@ global int label_topline init(FALSE);
 #ifdef NEXTPAGE_TOPLINE
 global int nextpage_topline init(FALSE);
 #endif
+global char *displayTitleTerm init(NULL);
 global int displayLink init(FALSE);
 global int retryAsHttp init(TRUE);
 global int showLineNum init(FALSE);
@@ -859,12 +861,17 @@ global char *pauth init(NULL);
 global Str proxy_auth_cookie init(NULL);
 global int UseExternalDirBuffer init(TRUE);
 global char *DirBufferCommand init("file:///$LIB/dirlist" CGI_EXTENSION);
+#ifdef USE_DICT
+global int UseDictCommand init(FALSE);
+global char *DictCommand init("file:///$LIB/w3mdict" CGI_EXTENSION);
+#endif				/* USE_DICT */
 global int ignore_null_img_alt init(TRUE);
 global int FoldTextarea init(FALSE);
 #define DEFAULT_URL_EMPTY	0
 #define DEFAULT_URL_CURRENT	1
 #define DEFAULT_URL_LINK	2
 global int DefaultURLString init(DEFAULT_URL_EMPTY);
+global int MarkAllPages init(FALSE);
 
 #ifdef USE_MIGEMO
 global int use_migemo init(FALSE);
@@ -973,6 +980,8 @@ global double image_scale init(100);
 #endif
 global int use_lessopen init(FALSE);
 
+global char *keymap_file init(KEYMAP_FILE);
+
 #ifdef JP_CHARSET
 #define is_kanji(s)    (IS_KANJI1((s)[0])&&IS_KANJI2((s)[1]))
 #define get_mctype(s)  (is_kanji(s)?PC_KANJI:GET_PCTYPE(*(s)))
