@@ -1,4 +1,4 @@
-/* $Id: frame.c,v 1.9 2002/01/25 14:59:14 ukai Exp $ */
+/* $Id: frame.c,v 1.16 2002/06/17 15:50:45 inu Exp $ */
 #include "fm.h"
 #include "parsetagx.h"
 #include "myctype.h"
@@ -20,13 +20,52 @@ KeyAbort(SIGNAL_ARG)
     LONGJMP(AbortLoading, 1);
 }
 
+static int
+parseFrameSetLength(char *s, char ***ret)
+{
+    int i, len;
+    char *p, *q, **lv;
+
+    i = 1;
+
+    if (s)
+	for (p = s; (p = strchr(p, ',')); ++p)
+	    ++i;
+    else
+	s = "*";
+
+    lv = New_N(char *, i);
+
+    for (i = 0, p = s;; ++p) {
+	SKIP_BLANKS(p);
+	len = strtol(p, &q, 10);
+
+	switch (*q) {
+	case '%':
+	    lv[i++] = Sprintf("%d%%", len)->ptr;
+	    break;
+	case '*':
+	    lv[i++] = "*";
+	    break;
+	default:
+	    lv[i++] = Sprintf("%d", len)->ptr;
+	    break;
+	}
+
+	if (!(p = strchr(q, ',')))
+	    break;
+    }
+
+    *ret = lv;
+    return i;
+}
+
 struct frameset *
 newFrameSet(struct parsed_tag *tag)
 {
     struct frameset *f;
     int i;
-    char *cols = NULL, *rows = NULL, *p, *q;
-    char *length[100];
+    char *cols = NULL, *rows = NULL;
 
     f = New(struct frameset);
     f->attr = F_FRAMESET;
@@ -34,78 +73,13 @@ newFrameSet(struct parsed_tag *tag)
     f->currentURL = NULL;
     parsedtag_get_value(tag, ATTR_COLS, &cols);
     parsedtag_get_value(tag, ATTR_ROWS, &rows);
-    i = 0;
-    if (cols) {
-	length[i] = p = cols;
-	while (*p != '\0')
-	    if (*p++ == ',') {
-		length[++i] = p;
-		if (i >= sizeof(length) / sizeof(length[0]) - 2)
-		    break;
-	    }
-	length[++i] = p + 1;
-    }
-    if (i > 1) {
-	f->col = i;
-	f->width = New_N(char *, i);
-	p = length[i];
-	do {
-	    i--;
-	    q = p - 2;
-	    p = length[i];
-	    switch (*q) {
-		Str tmp;
-	    case '%':
-		f->width[i] = allocStr(p, q - p + 1);
-		break;
-	    case '*':
-		f->width[i] = "*";
-		break;
-	    default:
-		tmp = Sprintf("%d", atoi(p));
-		f->width[i] = tmp->ptr;
-		break;
-	    }
-	} while (i);
-    }
-    else {
-	f->col = 1;
-	f->width = New_N(char *, 1);
-	f->width[0] = "*";
-    }
-    i = 0;
-    if (rows) {
-	length[i] = p = rows;
-	while (*p != '\0')
-	    if (*p++ == ',') {
-		length[++i] = p;
-		if (i >= sizeof(length) / sizeof(length[0]) - 2)
-		    break;
-	    }
-	length[++i] = p + 1;
-    }
-    if (i > 1) {
-	f->row = i;
-	f->height = New_N(char *, i);
-	p = length[i];
-	do {
-	    i--;
-	    q = p - 2;
-	    p = length[i];
-	    f->height[i] = allocStr(p, q - p + 1);
-	} while (i);
-    }
-    else {
-	f->row = 1;
-	f->height = New_N(char *, 1);
-	f->height[0] = "*";
-    }
-    i = f->row * f->col;
+    f->col = parseFrameSetLength(cols, &f->width);
+    f->row = parseFrameSetLength(rows, &f->height);
     f->i = 0;
+    i = f->row * f->col;
     f->frame = New_N(union frameset_element, i);
     do {
-	i--;
-	f->frame[i].element = NULL;
+	f->frame[--i].element = NULL;
     } while (i);
     return f;
 }
@@ -342,7 +316,12 @@ resetFrameElement(union frameset_element *f_element,
 	f_body->attr = F_BODY;
 	f_body->name = f_name;
 	f_body->url = parsedURL2Str(&buf->currentURL)->ptr;
-	if (buf->real_scheme == SCM_LOCAL) {
+	if (buf->mailcap_source) {
+	    f_body->source = buf->mailcap_source;
+	    f_body->flags |= FB_TODELETE;
+	    buf->mailcap_source = NULL;
+	}
+	else if (buf->real_scheme == SCM_LOCAL) {
 	    f_body->source = buf->sourcefile;
 	}
 	else {
@@ -385,7 +364,12 @@ frame_download_source(struct frame_body *b, ParsedURL *currentURL,
 	w3m_dump |= DUMP_FRAME;
 	buf = loadGeneralFile(b->url,
 			      baseURL ? baseURL : currentURL,
-			      b->referer, flag, b->request);
+			      b->referer, flag | RG_FRAME_SRC, b->request);
+#ifdef USE_SSL
+	/* XXX certificate? */
+	if (buf && buf != NO_BUFFER)
+	    b->ssl_certificate = buf->ssl_certificate;
+#endif
 	w3m_dump &= ~DUMP_FRAME;
 	is_redisplay = FALSE;
 	break;
@@ -399,7 +383,17 @@ frame_download_source(struct frame_body *b, ParsedURL *currentURL,
     b->url = parsedURL2Str(&buf->currentURL)->ptr;
     b->source = buf->sourcefile;
     b->type = buf->type;
-    if (buf->real_scheme != SCM_LOCAL) {
+    if (buf->mailcap_source) {
+	b->source = buf->mailcap_source;
+	b->flags |= FB_TODELETE;
+	buf->mailcap_source = NULL;
+    }
+    else if ((buf->real_scheme != SCM_LOCAL)
+#ifdef USE_IMAGE
+	     || (activeImage && !useExtImageViewer &&
+		 buf->real_type && !strncasecmp(buf->real_type, "image/", 6))
+#endif
+	) {
 	tmp = tmpfname(TMPF_FRAME, NULL);
 	rename(buf->sourcefile, tmp->ptr);
 	b->source = tmp->ptr;
