@@ -1,4 +1,4 @@
-/* $Id: menu.c,v 1.13 2002/01/16 02:51:37 ukai Exp $ */
+/* $Id: menu.c,v 1.15 2002/03/19 16:06:52 ukai Exp $ */
 /* 
  * w3m menu.c
  */
@@ -641,9 +641,9 @@ action_menu(Menu *menu)
 	if (item.type & MENU_FUNC) {
 	    CurrentKey = -1;
 	    CurrentKeyData = NULL;
-	    CurrentMenuData = item.data;
+	    CurrentCmdData = item.data;
 	    (*item.func) ();
-	    CurrentMenuData = NULL;
+	    CurrentCmdData = NULL;
 	}
     }
     else if (mselect == MENU_CLOSE) {
@@ -1327,8 +1327,13 @@ smChBuf(void)
 	return;
     for (i = 0, buf = Firstbuf; i < SelectV; i++, buf = buf->nextBuffer) ;
     Currentbuf = buf;
-    if (clear_buffer) {
-	for (buf = Firstbuf; buf != NULL; buf = buf->nextBuffer)
+    for (buf = Firstbuf; buf != NULL; buf = buf->nextBuffer) {
+	if (buf == Currentbuf)
+	    continue;
+#ifdef USE_IMAGE
+	deleteImage(buf);
+#endif
+	if (clear_buffer)
 	    tmpClearBuffer(buf);
     }
 }
