@@ -1,4 +1,4 @@
-/* $Id: terms.c,v 1.27 2001/12/25 16:54:45 ukai Exp $ */
+/* $Id: terms.c,v 1.32 2002/03/27 15:41:38 ukai Exp $ */
 /* 
  * An original curses library for EUC-kanji by Akinori ITO,     December 1989
  * revised by Akinori ITO, January 1995
@@ -42,6 +42,8 @@ void mouse_init(), mouse_end();
 int mouseActive = 0;
 #endif				/* USE_MOUSE */
 
+static char *title_str = NULL;
+
 static int tty;
 
 #include "terms.h"
@@ -474,22 +476,34 @@ writestr(char *s)
 #define MOVE(line,column)       writestr(tgoto(T_cm,column,line));
 
 #ifdef USE_MOUSE
-static struct mouse_term_info {
+#define W3M_TERM_INFO(name, title, mouse)	name, title, mouse
+#else
+#define W3M_TERM_INFO(name, title, mouse)	name, title
+#endif
+
+#define XTERM_TITLE	"\033]0;w3m: %s\007"
+#define SCREEN_TITLE	"\033k%s\033\134"
+
+/* *INDENT-OFF* */
+static struct w3m_term_info {
     char *term;
-    int flag;
-} xterm_mouse_term[] = {
-    {
-    "xterm", NEED_XTERM_ON | NEED_XTERM_OFF}, {
-    "kterm", NEED_XTERM_ON | NEED_XTERM_OFF}, {
-    "rxvt", NEED_XTERM_ON | NEED_XTERM_OFF},
+    char *title_str;
+#ifdef USE_MOUSE
+    int mouse_flag;
+#endif
+} w3m_term_info_list[] = {
+    {W3M_TERM_INFO("xterm", XTERM_TITLE, (NEED_XTERM_ON|NEED_XTERM_OFF))},
+    {W3M_TERM_INFO("kterm", XTERM_TITLE, (NEED_XTERM_ON|NEED_XTERM_OFF))},
+    {W3M_TERM_INFO("rxvt", XTERM_TITLE, (NEED_XTERM_ON|NEED_XTERM_OFF))},
+    {W3M_TERM_INFO("Eterm", XTERM_TITLE, (NEED_XTERM_ON|NEED_XTERM_OFF))},
+    {W3M_TERM_INFO("screen", SCREEN_TITLE, 0)},
 #ifdef __CYGWIN__
-    {
-    "cygwin", NEED_XTERM_ON},
+    {W3M_TERM_INFO("cygwin", NULL, NEED_XTERM_ON)},
 #endif
-    {
-    NULL, 0}
+    {W3M_TERM_INFO(NULL, NULL, 0)}
 };
-#endif
+#undef W3M_TERM_INFO
+/* *INDENT-ON * */
 
 int
 set_tty(void)
@@ -510,13 +524,22 @@ set_tty(void)
     init_win32_console_handle();
 #endif
     TerminalGet(tty, &d_ioval);
+    if (displayTitleTerm != NULL) {
+	struct w3m_term_info *p;
+	for (p = w3m_term_info_list; p->term != NULL; p++) {
+	    if (!strncmp(displayTitleTerm, p->term, strlen(p->term))) {
+		title_str = p->title_str;
+		break;
+	    }
+	}
+    }
 #ifdef USE_MOUSE
     {
 	char *term = getenv("TERM");
-	struct mouse_term_info *p;
-	for (p = xterm_mouse_term; p->term != NULL; p++) {
+	struct w3m_term_info *p;
+	for (p = w3m_term_info_list; p->term != NULL; p++) {
 	    if (!strncmp(term, p->term, strlen(p->term))) {
-		is_xterm = p->flag;
+		is_xterm = p->mouse_flag;
 		break;
 	    }
 	}
@@ -1837,6 +1860,15 @@ term_cbreak(void)
     term_noecho();
 }
 
+void
+term_title(char *s)
+{
+    if (!fmInitialized)
+        return;
+    if (title_str != NULL)
+        fprintf(ttyf, title_str, s);
+}
+
 char
 getch(void)
 {
@@ -1865,7 +1897,14 @@ wgetch(void)
 {
     char c;
 
-    read(tty, &c, 1);
+    /* read(tty, &c, 1); */
+    while (read(tty, &c, 1) < (ssize_t) 1) {
+	if (errno == EINTR || errno == EAGAIN)
+	    continue;
+	/* error happend on read(2) */
+	quitfm();
+	break;			/* unreachable */
+    }
     return c;
 }
 
@@ -2159,3 +2198,20 @@ flush_tty()
 {
     fflush(ttyf);
 }
+
+#ifdef USE_IMAGE
+void
+touch_cursor()
+{
+    touch_line();
+    touch_column(CurColumn);
+#ifdef JP_CHARSET
+    if (CurColumn > 0 &&
+	CHMODE(ScreenImage[CurLine]->lineprop[CurColumn]) == C_WCHAR2)
+	touch_column(CurColumn - 1);
+    else if (CurColumn < COLS - 1 &&
+	     CHMODE(ScreenImage[CurLine]->lineprop[CurColumn]) == C_WCHAR1)
+	touch_column(CurColumn + 1);
+#endif
+}
+#endif
